@@ -44,10 +44,8 @@ void MessageTest::testMainBodyPart()
     QCOMPARE(msg2->mainBodyPart("text/plain"), text);
     QCOMPARE(msg2->mainBodyPart("text/html"), (Content *)nullptr);
 
-    // Careful with removing content here.  If we remove one of the two contents
-    // (by adding it to another message), the multipart will automatically be
-    // converted to a single-part, deleting the other content!
-    msg2->clearContents(false);
+    msg2->takeContent(text);
+    msg2->takeContent(html);
 
     // multipart/alternative
     msg->contentType()->setMimeType("multipart/alternative");
@@ -712,6 +710,10 @@ void MessageTest::testGarbage_data()
     QTest::newRow("digits-overflow") << u"read-digits-overflow.mbox"_s;
     QTest::newRow("uninitialized-memory") << u"uninitialized-memory-use.mbox"_s;
     QTest::newRow("infinite-memory") << u"clusterfuzz-testcase-minimized-kmime_fuzzer-5255984894509056"_s;
+    QTest::newRow("assert") << u"clusterfuzz-testcase-minimized-kmime_fuzzer-5617955779182592"_s;
+    QTest::newRow("yenc-large-alloc") << u"clusterfuzz-testcase-minimized-kmime_fuzzer-4804196479336448"_s;
+    QTest::newRow("yenc-corrupt-size") << u"yenc-single-part.yenc"_s;
+    QTest::newRow("uuencode-no-filename") << u"clusterfuzz-testcase-minimized-kmime_fuzzer-6349101081100288"_s;
 }
 
 void MessageTest::testGarbage()
@@ -722,4 +724,16 @@ void MessageTest::testGarbage()
     QVERIFY(msg);
 }
 
+void MessageTest::testYenc()
+{
+    KMime::Message::Ptr msg = readAndParseMail(u"yenc-single-part.yenc"_s);
+    QVERIFY(msg);
+
+    QFile refFile(QLatin1StringView(TEST_DATA_DIR) + "/yenc-single-part.txt"_L1);
+    QVERIFY(refFile.open(QFile::ReadOnly));
+    QCOMPARE(msg->subject()->asUnicodeString(), "yEnc-Prefix: \"testfile.txt\" 584 yEnc bytes - yEnc test (1)"_L1);
+    QCOMPARE(msg->contents().size(), 2);
+    QCOMPARE(msg->contents()[1]->decodedBody(), refFile.readAll());
+}
+
 #include "moc_messagetest.cpp"
